@@ -8,9 +8,9 @@
  */
 vector<mdsize>
 find_nearest(const vector<vector<mdreal> >& book,
-	     const vector<mdreal>& x, const mdsize limit) {
+	     const vector<mdreal>& x, const mdsize limit,
+	     mt19937& twister) {
   mdreal rlnan = medusa::rnan();
-  mt19937 twister;
   
   /* Check if missing values. */
   mdsize nval = 0;
@@ -96,17 +96,22 @@ nro_impute(SEXP xdata_R, SEXP nsub_R, SEXP lag_R) {
   mdsize nsub = as<mdsize>(nsub_R);
   mdreal lag = as<mdreal>(lag_R);
   time_t stamp = time(NULL);
- 
+
   /* Check data. */
   vector<vector<mdreal> > xvect = nro::matrix2reals(xdata_R, 0.0);
   if(xvect.size() < 1) return CharacterVector("Empty input.");
 
+  /* Set up random numbers. */
+  string seedval = (long2string(nsub) + real2string(xvect[0][0]));
+  seed_seq seed(seedval.begin(), seedval.end());
+  mt19937 twister(seed);
+
   /* Fill in missing values. */
   time_t reset = stamp;
   vector<vector<mdreal> > data = xvect;
   for(mdsize i = 0; i < xvect.size(); i++) {
     vector<mdreal>& x = xvect[i];
-    vector<mdsize> neigh = find_nearest(data, x, nsub);
+    vector<mdsize> neigh = find_nearest(data, x, nsub, twister);
     for(mdsize k = 0; k < neigh.size(); k++) {
       mdsize ind = neigh[k];
       if(merge_values(x, data[ind])) break;
